@@ -5,11 +5,12 @@ Draupnir : Ancestral protein sequence reconstruction using a tree-structured Orn
 =======================
 """
 import torch
+from torch import nn
 import sys
 from collections import namedtuple
 #sys.path.append("./draupnir/src/draupnir")
 import draupnir.utils as DraupnirUtils
-from models_utils import *
+from draupnir.models_utils import *
 import pyro
 import pyro.distributions as dist
 SamplingOutput = namedtuple("SamplingOutput",["aa_sequences","latent_space","logits","phis","psis","mean_phi","mean_psi","kappa_phi","kappa_psi"])
